#
# spec file for package python-awx-cli
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-awx-cli
Version:        24.6.1
Release:        1.3
Summary:        CLI for the AWX Ansible web platform
License:        Apache-2.0
URL:            https://github.com/ansible/awx/tree/devel/awxkit
Source:         awx-%{version}.tar.gz
Source1:        LICENSE.md
BuildRequires:  %{python_module base}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
# SECTION
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module websocket-client}
# SECTION
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-PyYAML
Requires:       python-requests
Requires(post): update-alternatives
Requires(postun): update-alternatives

BuildArch:      noarch
%python_subpackages

%description
CLI to manage the AWX Ansible web platform

%prep
%autosetup -n awx-%{version}
cp %{SOURCE1} .
echo %{version} > VERSION

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/akit
%python_clone -a %{buildroot}%{_bindir}/awx
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%post
%python_install_alternative akit
%python_install_alternative awx

%postun
%python_uninstall_alternative akit
%python_uninstall_alternative awx

%files %{python_files}
%doc README.md
%license LICENSE.md
%{python_sitelib}/awxkit/
%{python_sitelib}/awxkit-%{version}.dist-info
%python_alternative %{_bindir}/akit
%python_alternative %{_bindir}/awx

%changelog
* Wed Jul  3 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 24.6.1:
  https://github.com/ansible/awx/releases/tag/24.6.1
  No CLI-related changes mentioned in the release notes
* Fri Jun 21 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 24.6.0:
  https://github.com/ansible/awx/releases/tag/24.6.0
  * Updated AWX CLI to patch users in order to properly assign them
    roles (@ArtsiomMusin #14053)
* Wed Jun  5 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 24.5.0:
  https://github.com/ansible/awx/releases/tag/24.5.0
  No CLI-related changes mentioned in the release notes
* Wed May 22 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 24.4.0:
  https://github.com/ansible/awx/releases/tag/24.4.0
  No CLI-related changes mentioned in the release notes
* Sun May 12 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 24.3.1:
  https://github.com/ansible/awx/releases/tag/24.3.1
  No CLI-related changes mentioned in the release notes
* Sun May 12 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 24.3.0:
  https://github.com/ansible/awx/releases/tag/24.3.0
  * Fixed awxkit uploads when re-running promote workflow
    (@shanemcd #15096)
* Sun May 12 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 24.2.0:
  https://github.com/ansible/awx/releases/tag/24.2.0
  No CLI-related changes mentioned in the release notes
* Sun May 12 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 24.1.0:
  https://github.com/ansible/awx/releases/tag/24.1.0
  No CLI-related changes mentioned in the release notes
* Sun May 12 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 24.0.0:
  https://github.com/ansible/awx/releases/tag/24.0.0
  No CLI-related changes mentioned in the release notes
* Sun May 12 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 23.9.0:
  https://github.com/ansible/awx/releases/tag/23.9.0
  * Updated the release doc to check for awxkit tar files
    (@thedoubl3j #14892)
  * Added the ability to use awxkit with websocket custom URLs
    (@CFSNM #14901)
  * Added support for Terraform credentials in awxkit (@CFSNM
    [#14902])
* Sun May 12 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 23.8.1:
  https://github.com/ansible/awx/releases/tag/23.8.1
  No CLI-related changes mentioned in the release notes
* Sun May 12 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 23.8.0:
  https://github.com/ansible/awx/releases/tag/23.8.0
  * Updated awxkit to allow to modify API base URL (@Zokormazo
    [#14835])
  * Fixed the way the API passes the awxkit base path to resources
    (@CFSNM #14862)
* Sun May 12 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 23.7.0:
  https://github.com/ansible/awx/releases/tag/23.7.0
  * Built the awxkit source distribution bundle to also upload to
    PyPI (@jbradberry #14757)
* Sat Jan 27 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package python-awx-cli: CLI to manage the AWX Ansible web
  platform (successor of the tower-cli)
